Class: Bosh::Cli::Client::Director
Constant Summary collapse
- DIRECTOR_HTTP_ERROR_CODES =
[400, 403, 404, 500]
- API_TIMEOUT =
86400 * 3
- CONNECT_TIMEOUT =
30
Instance Attribute Summary collapse
-
#director_uri ⇒ Object
readonly
Returns the value of attribute director_uri.
- #password ⇒ String
- #user ⇒ String
Instance Method Summary collapse
- #apply_resolutions(deployment_name, resolutions, options = {}) ⇒ Object
- #authenticated? ⇒ Boolean
- #cancel_task(task_id) ⇒ Object
- #change_job_state(deployment_name, manifest_yaml, job_name, index, new_state, options = {}) ⇒ Object
- #change_vm_resurrection(deployment_name, job_name, index, value) ⇒ Object
- #change_vm_resurrection_for_all(value) ⇒ Object
- #cleanup_ssh(deployment_name, job, user_regex, indexes, options = {}) ⇒ Object
- #create_backup ⇒ Object
- #create_property(deployment_name, property_name, value) ⇒ Object
- #create_user(username, password) ⇒ Object
- #delete_all_snapshots(deployment_name, options = {}) ⇒ Object
- #delete_deployment(name, options = {}) ⇒ Object
- #delete_property(deployment_name, property_name) ⇒ Object
- #delete_release(name, options = {}) ⇒ Object
- #delete_snapshot(deployment_name, snapshot_cid, options = {}) ⇒ Object
- #delete_stemcell(name, version, options = {}) ⇒ Object
- #delete_user(username) ⇒ Object
- #deploy(manifest_yaml, options = {}) ⇒ Object
- #download_resource(id) ⇒ Object
- #exists? ⇒ Boolean
- #fetch_backup ⇒ Object
- #fetch_logs(deployment_name, job_name, index, log_type, filters = nil, options = {}) ⇒ Object
- #fetch_vm_state(deployment_name, options = {}) ⇒ Object
- #get_current_time ⇒ Object
- #get_deployment(name) ⇒ Object
- #get_property(deployment_name, property_name) ⇒ Object
- #get_release(name) ⇒ Object
- #get_status ⇒ Object
- #get_task(task_id) ⇒ Object
- #get_task_output(task_id, offset, log_type = nil) ⇒ Object
- #get_task_result(task_id) ⇒ Object
- #get_task_result_log(task_id) ⇒ Object
- #get_task_state(task_id) ⇒ Object
- #get_time_difference ⇒ Object
- #get_version ⇒ Object
-
#initialize(director_uri, user = nil, password = nil, options = {}) ⇒ Director
constructor
Options can include: * :no_track => true - do not use
TaskTrackerfor long-runningrequest_and_trackcalls. - #list_deployments ⇒ Object
- #list_errands(deployment_name) ⇒ Object
- #list_locks ⇒ Object
- #list_problems(deployment_name) ⇒ Object
- #list_properties(deployment_name) ⇒ Object
- #list_recent_tasks(count = 30, verbose = 1) ⇒ Object
- #list_releases ⇒ Object
- #list_running_tasks(verbose = 1) ⇒ Object
- #list_snapshots(deployment_name, job = nil, index = nil) ⇒ Object
- #list_stemcells ⇒ Object
- #list_vms(name) ⇒ Object
- #login(username, password) ⇒ Object
- #match_packages(manifest_yaml) ⇒ Object
- #perform_cloud_scan(deployment_name, options = {}) ⇒ Object
- #rename_job(deployment_name, manifest_yaml, old_name, new_name, force = false, options = {}) ⇒ Object
-
#request_and_track(method, uri, options = {}) ⇒ Object
Perform director HTTP request and track director task (if request started one).
- #setup_ssh(deployment_name, job, index, user, public_key, password, options = {}) ⇒ Object
- #take_snapshot(deployment_name, job = nil, index = nil, options = {}) ⇒ Object
- #update_property(deployment_name, property_name, value) ⇒ Object
- #upload_and_track(method, uri, filename, options = {}) ⇒ Object
- #upload_release(filename, options = {}) ⇒ Object
- #upload_remote_release(release_location, options = {}) ⇒ Object
- #upload_remote_stemcell(stemcell_location, options = {}) ⇒ Object
- #upload_stemcell(filename, options = {}) ⇒ Object
- #uuid ⇒ Object
- #wait_until_ready ⇒ Object
Constructor Details
#initialize(director_uri, user = nil, password = nil, options = {}) ⇒ Director
Options can include:
- :no_track => true - do not use
TaskTrackerfor long-runningrequest_and_trackcalls
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/cli/client/director.rb', line 31 def initialize(director_uri, user = nil, password = nil, = {}) if director_uri.nil? || director_uri =~ /^\s*$/ raise DirectorMissing, 'no director URI given' end @director_uri = URI.parse(director_uri) @director_ip = Resolv.getaddresses(@director_uri.host).last @scheme = @director_uri.scheme @port = @director_uri.port @user = user @password = password @track_tasks = !.delete(:no_track) @num_retries = .fetch(:num_retries, 5) @retry_wait_interval = .fetch(:retry_wait_interval, 5) end |
Instance Attribute Details
#director_uri ⇒ Object (readonly)
Returns the value of attribute director_uri.
20 21 22 |
# File 'lib/cli/client/director.rb', line 20 def director_uri @director_uri end |
Instance Method Details
#apply_resolutions(deployment_name, resolutions, options = {}) ⇒ Object
444 445 446 447 448 449 450 451 452 |
# File 'lib/cli/client/director.rb', line 444 def apply_resolutions(deployment_name, resolutions, = {}) = .dup url = "/deployments/#{deployment_name}/problems" [:content_type] = 'application/json' [:payload] = JSON.generate('resolutions' => resolutions) request_and_track(:put, url, ) end |
#authenticated? ⇒ Boolean
73 74 75 76 77 78 79 80 81 |
# File 'lib/cli/client/director.rb', line 73 def authenticated? status = get_status # Backward compatibility: older directors return 200 # only for logged in users return true if !status.has_key?('version') !status['user'].nil? rescue DirectorError false end |
#cancel_task(task_id) ⇒ Object
518 519 520 521 522 523 |
# File 'lib/cli/client/director.rb', line 518 def cancel_task(task_id) response_code, body = delete("/task/#{task_id}") raise AuthError if response_code == 401 raise MissingTask, "No task##{task_id} found" if response_code == 404 [body, response_code] end |
#change_job_state(deployment_name, manifest_yaml, job_name, index, new_state, options = {}) ⇒ Object
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/cli/client/director.rb', line 283 def change_job_state(deployment_name, manifest_yaml, job_name, index, new_state, = {}) = .dup url = "/deployments/#{deployment_name}/jobs/#{job_name}" url += "/#{index}" if index url += "?state=#{new_state}" [:payload] = manifest_yaml [:content_type] = 'text/yaml' request_and_track(:put, url, ) end |
#change_vm_resurrection(deployment_name, job_name, index, value) ⇒ Object
297 298 299 300 301 |
# File 'lib/cli/client/director.rb', line 297 def change_vm_resurrection(deployment_name, job_name, index, value) url = "/deployments/#{deployment_name}/jobs/#{job_name}/#{index}/resurrection" payload = JSON.generate('resurrection_paused' => value) put(url, 'application/json', payload) end |
#change_vm_resurrection_for_all(value) ⇒ Object
303 304 305 306 307 |
# File 'lib/cli/client/director.rb', line 303 def change_vm_resurrection_for_all(value) url = "/resurrection" payload = JSON.generate('resurrection_paused' => value) put(url, 'application/json', payload) end |
#cleanup_ssh(deployment_name, job, user_regex, indexes, options = {}) ⇒ Object
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/cli/client/director.rb', line 262 def cleanup_ssh(deployment_name, job, user_regex, indexes, = {}) = .dup url = "/deployments/#{deployment_name}/ssh" payload = { 'command' => 'cleanup', 'deployment_name' => deployment_name, 'target' => { 'job' => job, 'indexes' => (indexes || []).compact }, 'params' => { 'user_regex' => user_regex } } [:payload] = JSON.generate(payload) [:content_type] = 'application/json' request_and_track(:post, url, ) end |
#create_backup ⇒ Object
525 526 527 |
# File 'lib/cli/client/director.rb', line 525 def create_backup request_and_track(:post, '/backups', {}) end |
#create_property(deployment_name, property_name, value) ⇒ Object
368 369 370 371 372 |
# File 'lib/cli/client/director.rb', line 368 def create_property(deployment_name, property_name, value) url = "/deployments/#{deployment_name}/properties" payload = JSON.generate('name' => property_name, 'value' => value) post(url, 'application/json', payload) end |
#create_user(username, password) ⇒ Object
83 84 85 86 87 |
# File 'lib/cli/client/director.rb', line 83 def create_user(username, password) payload = JSON.generate('username' => username, 'password' => password) response_code, _ = post('/users', 'application/json', payload) response_code == 204 end |
#delete_all_snapshots(deployment_name, options = {}) ⇒ Object
416 417 418 419 420 421 422 |
# File 'lib/cli/client/director.rb', line 416 def delete_all_snapshots(deployment_name, = {}) = .dup url = "/deployments/#{deployment_name}/snapshots" request_and_track(:delete, url, ) end |
#delete_deployment(name, options = {}) ⇒ Object
195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/cli/client/director.rb', line 195 def delete_deployment(name, = {}) = .dup force = .delete(:force) url = "/deployments/#{name}" extras = [] extras << ['force', 'true'] if force request_and_track(:delete, add_query_string(url, extras), ) end |
#delete_property(deployment_name, property_name) ⇒ Object
380 381 382 383 |
# File 'lib/cli/client/director.rb', line 380 def delete_property(deployment_name, property_name) url = "/deployments/#{deployment_name}/properties/#{property_name}" delete(url, 'application/json') end |
#delete_release(name, options = {}) ⇒ Object
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/cli/client/director.rb', line 207 def delete_release(name, = {}) = .dup force = .delete(:force) version = .delete(:version) url = "/releases/#{name}" extras = [] extras << ['force', 'true'] if force extras << ['version', version] if version request_and_track(:delete, add_query_string(url, extras), ) end |
#delete_snapshot(deployment_name, snapshot_cid, options = {}) ⇒ Object
424 425 426 427 428 429 430 |
# File 'lib/cli/client/director.rb', line 424 def delete_snapshot(deployment_name, snapshot_cid, = {}) = .dup url = "/deployments/#{deployment_name}/snapshots/#{snapshot_cid}" request_and_track(:delete, url, ) end |
#delete_stemcell(name, version, options = {}) ⇒ Object
183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/cli/client/director.rb', line 183 def delete_stemcell(name, version, = {}) = .dup force = .delete(:force) url = "/stemcells/#{name}/#{version}" extras = [] extras << ['force', 'true'] if force request_and_track(:delete, add_query_string(url, extras), ) end |
#delete_user(username) ⇒ Object
89 90 91 92 |
# File 'lib/cli/client/director.rb', line 89 def delete_user(username) response_code, _ = delete("/users/#{username}") response_code == 204 end |
#deploy(manifest_yaml, options = {}) ⇒ Object
221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/cli/client/director.rb', line 221 def deploy(manifest_yaml, = {}) = .dup recreate = .delete(:recreate) [:content_type] = 'text/yaml' [:payload] = manifest_yaml url = '/deployments' extras = [] extras << ['recreate', 'true'] if recreate request_and_track(:post, add_query_string(url, extras), ) end |
#download_resource(id) ⇒ Object
356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/cli/client/director.rb', line 356 def download_resource(id) status, tmp_file, _ = get("/resources/#{id}", nil, nil, {}, :file => true) if status == 200 tmp_file else raise DirectorError, "Cannot download resource `#{id}': HTTP status #{status}" end end |
#exists? ⇒ Boolean
51 52 53 54 55 56 57 58 |
# File 'lib/cli/client/director.rb', line 51 def exists? get_status true rescue AuthError true # For compatibility with directors that return 401 for /info rescue DirectorError false end |
#fetch_backup ⇒ Object
529 530 531 532 |
# File 'lib/cli/client/director.rb', line 529 def fetch_backup _, path, _ = get('/backups', nil, nil, {}, :file => true) path end |
#fetch_logs(deployment_name, job_name, index, log_type, filters = nil, options = {}) ⇒ Object
325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/cli/client/director.rb', line 325 def fetch_logs(deployment_name, job_name, index, log_type, filters = nil, = {}) = .dup url = "/deployments/#{deployment_name}/jobs/#{job_name}" url += "/#{index}/logs?type=#{log_type}&filters=#{filters}" status, task_id = request_and_track(:get, url, ) return nil if status != :done get_task_result(task_id) end |
#fetch_vm_state(deployment_name, options = {}) ⇒ Object
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/cli/client/director.rb', line 338 def fetch_vm_state(deployment_name, = {}) = .dup url = "/deployments/#{deployment_name}/vms?format=full" status, task_id = request_and_track(:get, url, ) if status != :done raise DirectorError, 'Failed to fetch VMs information from director' end output = get_task_result_log(task_id) output.to_s.split("\n").map do |vm_state| JSON.parse(vm_state) end end |
#get_current_time ⇒ Object
454 455 456 457 |
# File 'lib/cli/client/director.rb', line 454 def get_current_time _, _, headers = get('/info') Time.parse(headers[:date]) rescue nil end |
#get_deployment(name) ⇒ Object
157 158 159 160 |
# File 'lib/cli/client/director.rb', line 157 def get_deployment(name) _, body = get_json_with_status("/deployments/#{name}") body end |
#get_property(deployment_name, property_name) ⇒ Object
385 386 387 388 |
# File 'lib/cli/client/director.rb', line 385 def get_property(deployment_name, property_name) url = "/deployments/#{deployment_name}/properties/#{property_name}" get_json_with_status(url) end |
#get_release(name) ⇒ Object
142 143 144 |
# File 'lib/cli/client/director.rb', line 142 def get_release(name) get_json("/releases/#{name}") end |
#get_status ⇒ Object
114 115 116 |
# File 'lib/cli/client/director.rb', line 114 def get_status get_json('/info') end |
#get_task(task_id) ⇒ Object
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/cli/client/director.rb', line 465 def get_task(task_id) response_code, body = get("/tasks/#{task_id}") raise AuthError if response_code == 401 raise MissingTask, "Task #{task_id} not found" if response_code == 404 if response_code != 200 raise TaskTrackError, "Got HTTP #{response_code} " + 'while tracking task state' end JSON.parse(body) rescue JSON::ParserError raise TaskTrackError, 'Cannot parse task JSON, ' + 'incompatible director version' end |
#get_task_output(task_id, offset, log_type = nil) ⇒ Object
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/cli/client/director.rb', line 494 def get_task_output(task_id, offset, log_type = nil) uri = "/tasks/#{task_id}/output" uri += "?type=#{log_type}" if log_type headers = { 'Range' => "bytes=#{offset}-" } response_code, body, headers = get(uri, nil, nil, headers) if response_code == 206 && headers[:content_range].to_s =~ /bytes \d+-(\d+)\/\d+/ new_offset = $1.to_i + 1 else new_offset = nil # Delete the "Byte range unsatisfiable" message body = nil if response_code == 416 end # backward compatible with renaming soap log to cpi log if response_code == 204 && log_type == 'cpi' get_task_output(task_id, offset, 'soap') else [body, new_offset] end end |
#get_task_result(task_id) ⇒ Object
485 486 487 |
# File 'lib/cli/client/director.rb', line 485 def get_task_result(task_id) get_task(task_id)['result'] end |
#get_task_result_log(task_id) ⇒ Object
489 490 491 492 |
# File 'lib/cli/client/director.rb', line 489 def get_task_result_log(task_id) log, _ = get_task_output(task_id, 0, 'result') log end |
#get_task_state(task_id) ⇒ Object
481 482 483 |
# File 'lib/cli/client/director.rb', line 481 def get_task_state(task_id) get_task(task_id)['state'] end |
#get_time_difference ⇒ Object
459 460 461 462 463 |
# File 'lib/cli/client/director.rb', line 459 def get_time_difference # This includes the round-trip to director ctime = get_current_time ctime ? Time.now - ctime : 0 end |
#get_version ⇒ Object
110 111 112 |
# File 'lib/cli/client/director.rb', line 110 def get_version get_status['version'] end |
#list_deployments ⇒ Object
126 127 128 |
# File 'lib/cli/client/director.rb', line 126 def list_deployments get_json('/deployments') end |
#list_errands(deployment_name) ⇒ Object
130 131 132 |
# File 'lib/cli/client/director.rb', line 130 def list_errands(deployment_name) get_json("/deployments/#{deployment_name}/errands") end |
#list_locks ⇒ Object
534 535 536 |
# File 'lib/cli/client/director.rb', line 534 def list_locks get_json('/locks') end |
#list_problems(deployment_name) ⇒ Object
439 440 441 442 |
# File 'lib/cli/client/director.rb', line 439 def list_problems(deployment_name) url = "/deployments/#{deployment_name}/problems" get_json(url) end |
#list_properties(deployment_name) ⇒ Object
390 391 392 393 |
# File 'lib/cli/client/director.rb', line 390 def list_properties(deployment_name) url = "/deployments/#{deployment_name}/properties" get_json(url) end |
#list_recent_tasks(count = 30, verbose = 1) ⇒ Object
138 139 140 |
# File 'lib/cli/client/director.rb', line 138 def list_recent_tasks(count = 30, verbose = 1) get_json("/tasks?limit=#{count}&verbose=#{verbose}") end |
#list_releases ⇒ Object
122 123 124 |
# File 'lib/cli/client/director.rb', line 122 def list_releases get_json('/releases') end |
#list_running_tasks(verbose = 1) ⇒ Object
134 135 136 |
# File 'lib/cli/client/director.rb', line 134 def list_running_tasks(verbose = 1) get_json("/tasks?state=processing,cancelling,queued&verbose=#{verbose}") end |
#list_snapshots(deployment_name, job = nil, index = nil) ⇒ Object
407 408 409 410 411 412 413 414 |
# File 'lib/cli/client/director.rb', line 407 def list_snapshots(deployment_name, job = nil, index = nil) if job && index url = "/deployments/#{deployment_name}/jobs/#{job}/#{index}/snapshots" else url = "/deployments/#{deployment_name}/snapshots" end get_json(url) end |
#list_stemcells ⇒ Object
118 119 120 |
# File 'lib/cli/client/director.rb', line 118 def list_stemcells get_json('/stemcells') end |
#list_vms(name) ⇒ Object
162 163 164 165 |
# File 'lib/cli/client/director.rb', line 162 def list_vms(name) _, body = get_json_with_status("/deployments/#{name}/vms") body end |
#login(username, password) ⇒ Object
67 68 69 70 71 |
# File 'lib/cli/client/director.rb', line 67 def login(username, password) self.user = username self.password = password authenticated? end |
#match_packages(manifest_yaml) ⇒ Object
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/cli/client/director.rb', line 146 def match_packages(manifest_yaml) url = '/packages/matches' status, body = post(url, 'text/yaml', manifest_yaml) if status == 200 JSON.parse(body) else err((status, body)) end end |
#perform_cloud_scan(deployment_name, options = {}) ⇒ Object
432 433 434 435 436 437 |
# File 'lib/cli/client/director.rb', line 432 def perform_cloud_scan(deployment_name, = {}) = .dup url = "/deployments/#{deployment_name}/scans" request_and_track(:post, url, ) end |
#rename_job(deployment_name, manifest_yaml, old_name, new_name, force = false, options = {}) ⇒ Object
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/cli/client/director.rb', line 309 def rename_job(deployment_name, manifest_yaml, old_name, new_name, force = false, = {}) = .dup url = "/deployments/#{deployment_name}/jobs/#{old_name}" extras = [] extras << ['new_name', new_name] extras << ['force', 'true'] if force [:content_type] = 'text/yaml' [:payload] = manifest_yaml request_and_track(:put, add_query_string(url, extras), ) end |
#request_and_track(method, uri, options = {}) ⇒ Object
Perform director HTTP request and track director task (if request started one).
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/cli/client/director.rb', line 549 def request_and_track(method, uri, = {}) = .dup content_type = .delete(:content_type) payload = .delete(:payload) track_opts = http_status, _, headers = request(method, uri, content_type, payload) location = headers[:location] redirected = [302, 303].include? http_status task_id = nil if redirected if location =~ /\/tasks\/(\d+)\/?$/ # Looks like we received task URI task_id = $1 if @track_tasks tracker = Bosh::Cli::TaskTracking::TaskTracker.new(self, task_id, track_opts) status = tracker.track else status = :running end else status = :non_trackable end else status = :failed end [status, task_id] end |
#setup_ssh(deployment_name, job, index, user, public_key, password, options = {}) ⇒ Object
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/cli/client/director.rb', line 236 def setup_ssh(deployment_name, job, index, user, public_key, password, = {}) = .dup url = "/deployments/#{deployment_name}/ssh" payload = { 'command' => 'setup', 'deployment_name' => deployment_name, 'target' => { 'job' => job, 'indexes' => [index].compact }, 'params' => { 'user' => user, 'public_key' => public_key, 'password' => password } } [:payload] = JSON.generate(payload) [:content_type] = 'application/json' request_and_track(:post, url, ) end |
#take_snapshot(deployment_name, job = nil, index = nil, options = {}) ⇒ Object
395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/cli/client/director.rb', line 395 def take_snapshot(deployment_name, job = nil, index = nil, = {}) = .dup if job && index url = "/deployments/#{deployment_name}/jobs/#{job}/#{index}/snapshots" else url = "/deployments/#{deployment_name}/snapshots" end request_and_track(:post, url, ) end |
#update_property(deployment_name, property_name, value) ⇒ Object
374 375 376 377 378 |
# File 'lib/cli/client/director.rb', line 374 def update_property(deployment_name, property_name, value) url = "/deployments/#{deployment_name}/properties/#{property_name}" payload = JSON.generate('value' => value) put(url, 'application/json', payload) end |
#upload_and_track(method, uri, filename, options = {}) ⇒ Object
580 581 582 583 584 585 |
# File 'lib/cli/client/director.rb', line 580 def upload_and_track(method, uri, filename, = {}) file = FileWithProgressBar.open(filename, 'r') request_and_track(method, uri, .merge(:payload => file)) ensure file. if file end |
#upload_release(filename, options = {}) ⇒ Object
167 168 169 170 171 172 |
# File 'lib/cli/client/director.rb', line 167 def upload_release(filename, = {}) = .dup [:content_type] = 'application/x-compressed' upload_and_track(:post, releases_path(), filename, ) end |
#upload_remote_release(release_location, options = {}) ⇒ Object
174 175 176 177 178 179 180 181 |
# File 'lib/cli/client/director.rb', line 174 def upload_remote_release(release_location, = {}) = .dup payload = { 'location' => release_location } [:payload] = JSON.generate(payload) [:content_type] = 'application/json' request_and_track(:post, releases_path(), ) end |
#upload_remote_stemcell(stemcell_location, options = {}) ⇒ Object
101 102 103 104 105 106 107 108 |
# File 'lib/cli/client/director.rb', line 101 def upload_remote_stemcell(stemcell_location, = {}) = .dup payload = { 'location' => stemcell_location } [:payload] = JSON.generate(payload) [:content_type] = 'application/json' request_and_track(:post, '/stemcells', ) end |
#upload_stemcell(filename, options = {}) ⇒ Object
94 95 96 97 98 99 |
# File 'lib/cli/client/director.rb', line 94 def upload_stemcell(filename, = {}) = .dup [:content_type] = 'application/x-compressed' upload_and_track(:post, '/stemcells', filename, ) end |
#uuid ⇒ Object
47 48 49 |
# File 'lib/cli/client/director.rb', line 47 def uuid @uuid ||= get_status['uuid'] end |
#wait_until_ready ⇒ Object
60 61 62 63 64 65 |
# File 'lib/cli/client/director.rb', line 60 def wait_until_ready num_retries.times do return if exists? sleep retry_wait_interval end end |