Class: Bosh::Cli::Config

Inherits:
Object show all
Defined in:
lib/cli/config.rb

Constant Summary collapse

VALID_ID =
/^[-a-z0-9_.]+$/i

Class Attribute Summary collapse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(filename, work_dir = Dir.pwd) ⇒ Config

Returns a new instance of Config.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/cli/config.rb', line 42

def initialize(filename, work_dir = Dir.pwd)
  @filename = File.expand_path(filename || Bosh::Cli::DEFAULT_CONFIG_PATH)
  @work_dir = work_dir

  unless File.exists?(@filename)
    File.open(@filename, "w") { |f| Psych.dump({}, f) }
    File.chmod(0600, @filename)
  end

  @config_file = load_yaml_file(@filename, nil)

  unless @config_file.is_a?(Hash)
    @config_file = {} # Just ignore it if it's malformed
  end

rescue SystemCallError => e
  raise ConfigError, "Cannot read config file: #{e.message}"
end

Class Attribute Details

.colorize ⇒ Boolean

Returns Should CLI output be colorized?.

Returns:

  • (Boolean) —

    Should CLI output be colorized?



12
13
14
# File 'lib/cli/config.rb', line 12

def colorize
  @colorize
end

.commands ⇒ Hash<String,Bosh::Cli::CommandDefinition> (readonly)

Returns Available commands.

Returns:

  • (Hash<String,Bosh::Cli::CommandDefinition>) —

    Available commands



9
10
11
# File 'lib/cli/config.rb', line 9

def commands
  @commands
end

.interactive ⇒ Boolean

Returns Is CLI being used interactively?.

Returns:

  • (Boolean) —

    Is CLI being used interactively?



18
19
20
# File 'lib/cli/config.rb', line 18

def interactive
  @interactive
end

.max_parallel_downloads ⇒ Integer

Returns CLI max parallel downloads.

Returns:

  • (Integer) —

    CLI max parallel downloads



24
25
26
# File 'lib/cli/config.rb', line 24

def max_parallel_downloads
  @max_parallel_downloads
end

.output ⇒ IO

Returns Where output goes.

Returns:

  • (IO) —

    Where output goes



15
16
17
# File 'lib/cli/config.rb', line 15

def output
  @output
end

.poll_interval ⇒ Integer

Returns CLI polling interval.

Returns:

  • (Integer) —

    CLI polling interval



21
22
23
# File 'lib/cli/config.rb', line 21

def poll_interval
  @poll_interval
end

Instance Attribute Details

#filename ⇒ Object (readonly)

Returns the value of attribute filename.



236
237
238
# File 'lib/cli/config.rb', line 236

def filename
  @filename
end

Class Method Details

.register_command(command) ⇒ void

This method returns an undefined value.

Register command with BOSH CLI

Parameters:

  • command (Bosh::Cli::CommandDefinition)


35
36
37
38
39
40
# File 'lib/cli/config.rb', line 35

def self.register_command(command)
  if @commands.has_key?(command.usage)
    raise CliError, "Duplicate command `#{command.usage}'"
  end
  @commands[command.usage] = command
end

Instance Method Details

#aliases(category) ⇒ Object



87
88
89
90
91
92
93
# File 'lib/cli/config.rb', line 87

def aliases(category)
  if @config_file.has_key?("aliases") && @config_file["aliases"].is_a?(Hash)
    @config_file["aliases"][category.to_s]
  else
    nil
  end
end

#credentials_for(target) ⇒ Hash

Returns Director credentials.

Returns:

  • (Hash) —

    Director credentials



62
63
64
65
66
67
68
69
70
71
# File 'lib/cli/config.rb', line 62

def credentials_for(target)
  if @config_file["auth"].is_a?(Hash) && @config_file["auth"][target]
    @config_file["auth"][target]
  else
    {
      "username" => nil,
      "password" => nil
    }
  end
end

#deployment ⇒ String?

Read the deployment configuration. Return the deployment for the current target.

Returns:

  • (String?) —

    The deployment path for the current target.



135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/cli/config.rb', line 135

def deployment
  return nil if target.nil?
  if @config_file.has_key?("deployment")
    if is_old_deployment_config?
      set_deployment(@config_file["deployment"])
      save
    end
    if @config_file["deployment"].is_a?(Hash)
      return @config_file["deployment"][target]
    end
  end
end

#is_old_deployment_config? ⇒ Boolean

Deployment used to be a string that was only stored for your current target. As soon as you switched targets, the deployment was erased. If the user has the old config we convert it to the new config.

Returns:

  • (Boolean) —

    Whether config is using the old deployment format.



127
128
129
# File 'lib/cli/config.rb', line 127

def is_old_deployment_config?
  @config_file["deployment"].is_a?(String)
end

#max_parallel_downloads ⇒ Integer

Read the max parallel downloads configuration.

Returns:

  • (Integer) —

    The maximum number of parallel downloads



204
205
206
# File 'lib/cli/config.rb', line 204

def max_parallel_downloads
  self.class.max_parallel_downloads || @config_file.fetch("max_parallel_downloads", 1)
end

#password(target) ⇒ String

Returns Password associated with target.

Parameters:

  • target (String) —

    Target director url

Returns:

  • (String) —

    Password associated with target



117
118
119
# File 'lib/cli/config.rb', line 117

def password(target)
  credentials_for(target)["password"]
end

#read(attr, try_local_first = true) ⇒ Object



208
209
210
211
212
213
214
215
216
# File 'lib/cli/config.rb', line 208

def read(attr, try_local_first = true)
  attr = attr.to_s
  if try_local_first && @config_file[@work_dir].is_a?(Hash) &&
      @config_file[@work_dir].has_key?(attr)
    @config_file[@work_dir][attr]
  else
    @config_file[attr]
  end
end

#release ⇒ Object



185
186
187
# File 'lib/cli/config.rb', line 185

def release
  read(:release, false)
end

#release=(value) ⇒ Object



189
190
191
# File 'lib/cli/config.rb', line 189

def release=(value)
  write_global(:release, value)
end

#resolve_alias(category, alias_name) ⇒ Object



95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/cli/config.rb', line 95

def resolve_alias(category, alias_name)
  category = category.to_s

  if @config_file.has_key?("aliases") &&
      @config_file["aliases"].is_a?(Hash) &&
      @config_file["aliases"].has_key?(category) &&
      @config_file["aliases"][category].is_a?(Hash) &&
      !@config_file["aliases"][category][alias_name].blank?
    @config_file["aliases"][category][alias_name].to_s
  else
    nil
  end
end

#save ⇒ Object



227
228
229
230
231
232
233
234
# File 'lib/cli/config.rb', line 227

def save
  File.open(@filename, "w") do |f|
    Psych.dump(@config_file, f)
  end

rescue SystemCallError => e
  raise ConfigError, e.message
end

#set_alias(category, alias_name, value) ⇒ Object



81
82
83
84
85
# File 'lib/cli/config.rb', line 81

def set_alias(category, alias_name, value)
  @config_file["aliases"] ||= {}
  @config_file["aliases"][category.to_s] ||= {}
  @config_file["aliases"][category.to_s][alias_name] = value
end

#set_credentials(target, username, password) ⇒ Object



73
74
75
76
77
78
79
# File 'lib/cli/config.rb', line 73

def set_credentials(target, username, password)
  @config_file["auth"] ||= {}
  @config_file["auth"][target] = {
    "username" => username,
    "password" => password
  }
end

#set_deployment(deployment_file_path) ⇒ Object

Sets the deployment file for the current target. If the deployment is the old deployment configuration, it will turn it into the format.

Parameters:

  • deployment_file_path (String) —

    The string path to the deployment file.

Raises:



154
155
156
157
158
159
# File 'lib/cli/config.rb', line 154

def set_deployment(deployment_file_path)
  raise MissingTarget, "Must have a target set" if target.nil?
  @config_file["deployment"] = {} if is_old_deployment_config?
  @config_file["deployment"] ||= {}
  @config_file["deployment"][target] = deployment_file_path
end

#target ⇒ Object



161
162
163
# File 'lib/cli/config.rb', line 161

def target
  read(:target, false)
end

#target=(value) ⇒ Object



165
166
167
# File 'lib/cli/config.rb', line 165

def target=(value)
  write_global(:target, value)
end

#target_name ⇒ Object



169
170
171
# File 'lib/cli/config.rb', line 169

def target_name
  read(:target_name, false)
end

#target_name=(value) ⇒ Object



173
174
175
# File 'lib/cli/config.rb', line 173

def target_name=(value)
  write_global(:target_name, value)
end

#target_uuid ⇒ Object



193
194
195
# File 'lib/cli/config.rb', line 193

def target_uuid
  read(:target_uuid, false)
end

#target_uuid=(value) ⇒ Object



197
198
199
# File 'lib/cli/config.rb', line 197

def target_uuid=(value)
  write_global(:target_uuid, value)
end

#target_version ⇒ Object



177
178
179
# File 'lib/cli/config.rb', line 177

def target_version
  read(:target_version, false)
end

#target_version=(value) ⇒ Object



181
182
183
# File 'lib/cli/config.rb', line 181

def target_version=(value)
  write_global(:target_version, value)
end

#username(target) ⇒ String

Returns Username associated with target.

Parameters:

  • target (String) —

    Target director url

Returns:

  • (String) —

    Username associated with target



111
112
113
# File 'lib/cli/config.rb', line 111

def username(target)
  credentials_for(target)["username"]
end

#write(attr, value) ⇒ Object



218
219
220
221
# File 'lib/cli/config.rb', line 218

def write(attr, value)
  @config_file[@work_dir] ||= {}
  @config_file[@work_dir][attr.to_s] = value
end

#write_global(attr, value) ⇒ Object



223
224
225
# File 'lib/cli/config.rb', line 223

def write_global(attr, value)
  @config_file[attr.to_s] = value
end