Class: Bosh::Cli::Config
Constant Summary collapse
- VALID_ID =
/^[-a-z0-9_.]+$/i
Class Attribute Summary collapse
-
.colorize ⇒ Boolean
Should CLI output be colorized?.
-
.commands ⇒ Hash<String,Bosh::Cli::CommandDefinition>
readonly
Available commands.
-
.interactive ⇒ Boolean
Is CLI being used interactively?.
-
.max_parallel_downloads ⇒ Integer
CLI max parallel downloads.
-
.output ⇒ IO
Where output goes.
-
.poll_interval ⇒ Integer
CLI polling interval.
Instance Attribute Summary collapse
-
#filename ⇒ Object
readonly
Returns the value of attribute filename.
Class Method Summary collapse
-
.register_command(command) ⇒ void
Register command with BOSH CLI.
Instance Method Summary collapse
- #aliases(category) ⇒ Object
-
#credentials_for(target) ⇒ Hash
Director credentials.
-
#deployment ⇒ String?
Read the deployment configuration.
-
#initialize(filename, work_dir = Dir.pwd) ⇒ Config
constructor
A new instance of Config.
-
#is_old_deployment_config? ⇒ Boolean
Deployment used to be a string that was only stored for your current target.
-
#max_parallel_downloads ⇒ Integer
Read the max parallel downloads configuration.
-
#password(target) ⇒ String
Password associated with target.
- #read(attr, try_local_first = true) ⇒ Object
- #resolve_alias(category, alias_name) ⇒ Object
- #save ⇒ Object
- #set_alias(category, alias_name, value) ⇒ Object
- #set_credentials(target, username, password) ⇒ Object
-
#set_deployment(deployment_file_path) ⇒ Object
Sets the deployment file for the current target.
-
#username(target) ⇒ String
Username associated with target.
- #write(attr, value) ⇒ Object
- #write_global(attr, value) ⇒ Object
Constructor Details
#initialize(filename, work_dir = Dir.pwd) ⇒ Config
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/cli/config.rb', line 42 def initialize(filename, work_dir = Dir.pwd) @filename = File.(filename || Bosh::Cli::DEFAULT_CONFIG_PATH) @work_dir = work_dir unless File.exists?(@filename) File.open(@filename, "w") { |f| Psych.dump({}, f) } File.chmod(0600, @filename) end @config_file = load_yaml_file(@filename, nil) unless @config_file.is_a?(Hash) @config_file = {} # Just ignore it if it's malformed end rescue SystemCallError => e raise ConfigError, "Cannot read config file: #{e.message}" end |
Class Attribute Details
.colorize ⇒ Boolean
12 13 14 |
# File 'lib/cli/config.rb', line 12 def colorize @colorize end |
.commands ⇒ Hash<String,Bosh::Cli::CommandDefinition> (readonly)
9 10 11 |
# File 'lib/cli/config.rb', line 9 def commands @commands end |
.interactive ⇒ Boolean
18 19 20 |
# File 'lib/cli/config.rb', line 18 def interactive @interactive end |
.max_parallel_downloads ⇒ Integer
24 25 26 |
# File 'lib/cli/config.rb', line 24 def max_parallel_downloads @max_parallel_downloads end |
.output ⇒ IO
15 16 17 |
# File 'lib/cli/config.rb', line 15 def output @output end |
.poll_interval ⇒ Integer
21 22 23 |
# File 'lib/cli/config.rb', line 21 def poll_interval @poll_interval end |
Instance Attribute Details
#filename ⇒ Object (readonly)
Returns the value of attribute filename.
207 208 209 |
# File 'lib/cli/config.rb', line 207 def filename @filename end |
Class Method Details
.register_command(command) ⇒ void
This method returns an undefined value.
Register command with BOSH CLI
35 36 37 38 39 40 |
# File 'lib/cli/config.rb', line 35 def self.register_command(command) if @commands.has_key?(command.usage) raise CliError, "Duplicate command `#{command.usage}'" end @commands[command.usage] = command end |
Instance Method Details
#aliases(category) ⇒ Object
87 88 89 90 91 92 93 |
# File 'lib/cli/config.rb', line 87 def aliases(category) if @config_file.has_key?("aliases") && @config_file["aliases"].is_a?(Hash) @config_file["aliases"][category.to_s] else nil end end |
#credentials_for(target) ⇒ Hash
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cli/config.rb', line 62 def credentials_for(target) if @config_file["auth"].is_a?(Hash) && @config_file["auth"][target] @config_file["auth"][target] else { "username" => nil, "password" => nil } end end |
#deployment ⇒ String?
Read the deployment configuration. Return the deployment for the current target.
135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/cli/config.rb', line 135 def deployment return nil if target.nil? if @config_file.has_key?("deployment") if is_old_deployment_config? set_deployment(@config_file["deployment"]) save end if @config_file["deployment"].is_a?(Hash) return @config_file["deployment"][target] end end end |
#is_old_deployment_config? ⇒ Boolean
Deployment used to be a string that was only stored for your current target. As soon as you switched targets, the deployment was erased. If the user has the old config we convert it to the new config.
127 128 129 |
# File 'lib/cli/config.rb', line 127 def is_old_deployment_config? @config_file["deployment"].is_a?(String) end |
#max_parallel_downloads ⇒ Integer
Read the max parallel downloads configuration.
175 176 177 |
# File 'lib/cli/config.rb', line 175 def max_parallel_downloads self.class.max_parallel_downloads || @config_file.fetch("max_parallel_downloads", 1) end |
#password(target) ⇒ String
117 118 119 |
# File 'lib/cli/config.rb', line 117 def password(target) credentials_for(target)["password"] end |
#read(attr, try_local_first = true) ⇒ Object
179 180 181 182 183 184 185 186 187 |
# File 'lib/cli/config.rb', line 179 def read(attr, try_local_first = true) attr = attr.to_s if try_local_first && @config_file[@work_dir].is_a?(Hash) && @config_file[@work_dir].has_key?(attr) @config_file[@work_dir][attr] else @config_file[attr] end end |
#resolve_alias(category, alias_name) ⇒ Object
95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/cli/config.rb', line 95 def resolve_alias(category, alias_name) category = category.to_s if @config_file.has_key?("aliases") && @config_file["aliases"].is_a?(Hash) && @config_file["aliases"].has_key?(category) && @config_file["aliases"][category].is_a?(Hash) && !@config_file["aliases"][category][alias_name].blank? @config_file["aliases"][category][alias_name].to_s else nil end end |
#save ⇒ Object
198 199 200 201 202 203 204 205 |
# File 'lib/cli/config.rb', line 198 def save File.open(@filename, "w") do |f| Psych.dump(@config_file, f) end rescue SystemCallError => e raise ConfigError, e. end |
#set_alias(category, alias_name, value) ⇒ Object
81 82 83 84 85 |
# File 'lib/cli/config.rb', line 81 def set_alias(category, alias_name, value) @config_file["aliases"] ||= {} @config_file["aliases"][category.to_s] ||= {} @config_file["aliases"][category.to_s][alias_name] = value end |
#set_credentials(target, username, password) ⇒ Object
73 74 75 76 77 78 79 |
# File 'lib/cli/config.rb', line 73 def set_credentials(target, username, password) @config_file["auth"] ||= {} @config_file["auth"][target] = { "username" => username, "password" => password } end |
#set_deployment(deployment_file_path) ⇒ Object
Sets the deployment file for the current target. If the deployment is the old deployment configuration, it will turn it into the format.
154 155 156 157 158 159 |
# File 'lib/cli/config.rb', line 154 def set_deployment(deployment_file_path) raise MissingTarget, "Must have a target set" if target.nil? @config_file["deployment"] = {} if is_old_deployment_config? @config_file["deployment"] ||= {} @config_file["deployment"][target] = deployment_file_path end |
#username(target) ⇒ String
111 112 113 |
# File 'lib/cli/config.rb', line 111 def username(target) credentials_for(target)["username"] end |
#write(attr, value) ⇒ Object
189 190 191 192 |
# File 'lib/cli/config.rb', line 189 def write(attr, value) @config_file[@work_dir] ||= {} @config_file[@work_dir][attr.to_s] = value end |
#write_global(attr, value) ⇒ Object
194 195 196 |
# File 'lib/cli/config.rb', line 194 def write_global(attr, value) @config_file[attr.to_s] = value end |